# Internal API reference

## utility functions

[smart_read](api_reference/apiref_smartread.rst)
[get_masks](api_reference/apiref_getmasks.rst)
[utils](api_reference/apiref_utils.rst)

## Relative coordinate handling

[RelCoord](api_reference/apiref_RelCoord.rst)
